@@ -55,12 +55,12 @@ In the example above, #[derive([`Cast`])] makes the value of `UdpHdr`
 of `UdpHdr` `endian-flip`pable.
 
 Trait [`EncastMem`] provides methods to `encast` from memory, and
-trait [`DecastMem`] provides methods to `decast` to memory.  The type
-of the value(s) can be explicitly specified as the generic type parameter
-of their methods or implicitly specified so that the Rust compiler can
-infer.  Their methods whose names end with 'f' flip the endianness of
-the results.  The endianness of bytes is specified in their argument.
-[`BE`] is an alias of [`Endian`]`::Big`, which means Big-Endian.
+trait [`DecastMem`] provides methods to `decast` to memory.  The
+generic type parameters of their methods can be omitted where the Rust
+compiler can infer them.  Their methods whose names end with 'f' flip
+the endianness of the results.  The endianness of bytes is specified
+in their argument.  [`BE`] is an alias of [`Endian`]`::Big`, which
+means Big-Endian.
 
 Note: [UDP] is one of the fundamental protocols in the internet
 protocol suite.
@@ -211,6 +211,9 @@ assert_eq! requires them.  This crate works without them.
 This crate provides methods for encoding and decoding numeric
 variables, arrays and structures in little-endian and big-endian.
 
+Two types of endianness is defined in enum [`Endian`]: relative endian
+(Native vs. Swapped) and absolute endian (Little vs. Big).
+
 ## List of traits to mark characteristics of types
 
 * [`Cast`] marks types as `encast`able / `decast`able
@@ -252,7 +255,11 @@ If successful, they return the number of resulting bytes.
 The endianness of resulting bytes is specified in the arguments of
 `decastf` and `decastvf`.
 
-For more information, please see the description of each trait.
+Because this crate is very small, you can easily find a way to create
+your own traits to `encast` / `decast` on your system if the current
+API does not match your requirements.
+
+For more information, please see the description of each trait and enum.
 
  */
 
